Module control

Module control 

Loop runtime state aliases.

Structs

InferenceError
Inference error emitted by the loop and consumed by telemetry plugins.
SuspendedCallState
Per-tool-call suspended state stored at __tool_call_scope.<call_id>.suspended_call.
ToolCallResume
Resume input payload attached to a suspended tool call.
ToolCallState
Durable per-tool-call runtime state.

Enums

ResumeDecisionAction
Action to apply for a suspended tool call.
ToolCallStateAction
Action type for ToolCallState reducer.
ToolCallStatus
Tool call lifecycle status for suspend/resume capable execution.