Tool execution utilities.
Structs
- Tool
Execution - Result of one tool call execution.
Functions
- collect_
patches - Collect patches from executions.
- execute_
single_ tool - Execute a single tool call.
- execute_
single_ tool_ with_ scope - Execute a single tool call with an optional scope context.
- execute_
tools_ parallel - Execute tool calls in parallel using the same state snapshot for every call.
- execute_
tools_ sequential - Execute tool calls sequentially, applying each resulting patch before the next call.