Loop runtime state aliases.
Structs
- Inference
Error - Inference error emitted by the loop and consumed by telemetry plugins.
- Suspended
Call State - Per-tool-call suspended state stored at
__tool_call_scope.<call_id>.suspended_call. - Tool
Call Resume - Resume input payload attached to a suspended tool call.
- Tool
Call State - Durable per-tool-call runtime state.
Enums
- Resume
Decision Action - Action to apply for a suspended tool call.
- Tool
Call State Action - Action type for
ToolCallStatereducer. - Tool
Call Status - Tool call lifecycle status for suspend/resume capable execution.