Module control

Module control 

Loop runtime state aliases.

Structs

InferenceError
Inference error emitted by the loop and consumed by telemetry plugins.
InferenceErrorState
Durable inference-error envelope persisted at state["__inference_error"].
SuspendedToolCallsState
Durable suspended tool-call map persisted at state["__suspended_tool_calls"].
ToolCallResume
Resume input payload attached to a suspended tool call.
ToolCallState
Durable per-tool-call runtime state.
ToolCallStatesMap
Durable per-call runtime map persisted at state["__tool_call_states"].

Enums

ResumeDecisionAction
Action to apply for a suspended tool call.
ToolCallStatus
Tool call lifecycle status for suspend/resume capable execution.