Loop runtime state aliases.
Structs
- Inference
Error - Inference error emitted by the loop and consumed by telemetry plugins.
- Inference
Error State - Durable inference-error envelope persisted at
state["__inference_error"]. - Suspended
Tool Calls State - Durable suspended tool-call map persisted at
state["__suspended_tool_calls"]. - Tool
Call Resume - Resume input payload attached to a suspended tool call.
- Tool
Call State - Durable per-tool-call runtime state.
- Tool
Call States Map - Durable per-call runtime map persisted at
state["__tool_call_states"].
Enums
- Resume
Decision Action - Action to apply for a suspended tool call.
- Tool
Call Status - Tool call lifecycle status for suspend/resume capable execution.