pub trait ToolExecutor: Send + Sync {
// Required methods
fn execute<'life0, 'life1, 'async_trait>(
&'life0 self,
request: ToolExecutionRequest<'life1>,
) -> Pin<Box<dyn Future<Output = Result<Vec<ToolExecutionResult>, ToolExecutorError>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn name(&self) -> &'static str;
// Provided methods
fn requires_parallel_patch_conflict_check(&self) -> bool { ... }
fn decision_replay_policy(&self) -> DecisionReplayPolicy { ... }
}Expand description
Strategy abstraction for tool execution.
Required Methods
fn execute<'life0, 'life1, 'async_trait>(
&'life0 self,
request: ToolExecutionRequest<'life1>,
) -> Pin<Box<dyn Future<Output = Result<Vec<ToolExecutionResult>, ToolExecutorError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Provided Methods
Sourcefn requires_parallel_patch_conflict_check(&self) -> bool
fn requires_parallel_patch_conflict_check(&self) -> bool
Whether apply step should enforce parallel patch conflict checks.
Sourcefn decision_replay_policy(&self) -> DecisionReplayPolicy
fn decision_replay_policy(&self) -> DecisionReplayPolicy
How runtime should replay resolved suspend decisions for this executor.